@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
  *
- * Copyright (C) 2012 Colin Walters <walters@verbum.org>.
+ * Copyright (C) 2012,2013 Colin Walters <walters@verbum.org>.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,8 +25,24 @@
 
 G_BEGIN_DECLS
 
-#include <gsystem-local-alloc.h>
+#define gs_transfer_out_value(outp, srcp) G_STMT_START {   \
+  if (outp)                                                \
+    {                                                      \
+      *(outp) = *(srcp);                                   \
+      *(srcp) = NULL;                                      \
+    }                                                      \
+  } G_STMT_END;
+
+#include <gsystem-console.h>
 #include <gsystem-file-utils.h>
+#include <gsystem-shutil.h>
+#if GLIB_CHECK_VERSION(2,34,0)
+#include <gsystem-subprocess.h>
+#endif
+#include <gsystem-log.h>
+#ifndef _GSYSTEM_NO_LOCAL_ALLOC
+#include <gsystem-local-alloc.h>
+#endif
 
 G_END_DECLS
 
